<?php

/*
*	Register bulk actions
*/
function tsseph_register_bulk_action($bulk_actions) {
    $bulk_actions['export_posta'] = __( 'Podací hárok export (XML)', 'spirit-eph');
    $bulk_actions['export_posta_api'] = __( 'Podací hárok odoslať (API)', 'spirit-eph');
    return $bulk_actions;
}

/*
*	Actions to apply when user selects XML or API bulk action
*/
function tsseph_bulk_action_handler( $redirect_to, $doaction, $post_ids ) {
	
	//XML
	if ( $doaction === 'export_posta' ) {
	
		$eph_sets = tsseph_get_EPH($post_ids);

		//Delete existing zip 
		if(file_exists(plugin_dir_path( dirname(__FILE__) ) . 'export/EPH.zip')) {
			unlink(plugin_dir_path( dirname(__FILE__) ) . 'export/EPH.zip'); 
		}

		//Put all xml exports into one zip
		$zip = new ZipArchive();
		$zip->open(plugin_dir_path( dirname(__FILE__) ) . 'export/EPH.zip', ZIPARCHIVE::CREATE);

		$unlink_arr = array();

		foreach ($eph_sets as $key => $EPH) {

			$filename = plugin_dir_path( dirname(__FILE__) ) . 'export/EPH-' . $key . '.xml'; 
			$myfile = fopen($filename, "w") or die("Unable to open file!");
			fwrite($myfile, $EPH->asXML());
			fclose($myfile);  

			$zip->addFile($filename,'EPH-' . $key . '.xml');
			$unlink_arr[] = $filename;
		}

		$zip->close(); 

		//Delete the former xmls
		foreach($unlink_arr as $filename) { 
			unlink($filename); 
		}

		$redirect_to = remove_query_arg('exported_orders_api', $redirect_to);
		$redirect_to = add_query_arg( 'exported_orders', count($post_ids) , $redirect_to );
	}

	//API
  	else if ( $doaction === 'export_posta_api' ) {
  
		$tsseph_options = get_option( 'tsseph_options' ); 

		$error_msg = "";
		$orders_sent = array();
		$orders_not_sent = array();

		$auth = tsseph_posta_api_get_auth();

		$eph_sets = tsseph_get_EPH_API($post_ids);

		foreach ($eph_sets as $eph_set) {

			$contract = "false";

			//Set contract to true if Aktualne podacie cislo exists
			if (!empty($tsseph_options['AktualnePodCislo'])) $contract = "true";

			$service_param = array (
				'auth' => $auth,
				'EPH' => $eph_set['EPH'],
				'contract' => $contract
			);

			//write_log($service_param);

			$responseObj = tsseph_posta_api('importSheet',$service_param);

			//Check status 
			$status_param = array(
				'auth' => $auth,
				'sheetId' => $responseObj->sheetId
			);

			//Set Sheet ID
			foreach($post_ids as $post_id) {
				update_post_meta($post_id, 'tsseph_sheet_id', $responseObj->sheetId);
				update_post_meta($post_id, 'tsseph_tracking_no', '');
			}

			$statusObj = tsseph_posta_api('getSheetStatus',$status_param);

			//write_log($statusObj);

			if ($statusObj->sheetStatus == 'import_failed') {
				foreach($eph_set['OrderNumbers'] as $order_number) {
					$orders_not_sent[] =  $order_number;
				}
				
				if (is_array($statusObj->sheetErrorReport->error)) {
					foreach($statusObj->sheetErrorReport->error as $error_report) {
						$error_msg .= $error_report->attr . ' ' .tsseph_get_error_reason($error_report->reason) . ' ';
					}
				} 
				else {
						$error_msg .= $statusObj->sheetErrorReport->error->attr . ' ' . tsseph_get_error_reason($statusObj->sheetErrorReport->error->reason) . ' ';
				}

			} 
			else {
				foreach($eph_set['OrderNumbers'] as $order_number) {
					$orders_sent[] =  $order_number;
				}				
			}
		}

		$redirect_to = remove_query_arg('exported_orders', $redirect_to);
    	$redirect_to = add_query_arg(
			array(
				'exported_orders_api' => count($post_ids),
				'eph_status' => $error_msg,
				'orders_sent' => implode(',',$orders_sent),
				'orders_not_sent' => implode(',',$orders_not_sent)
			), 
			$redirect_to 
		);
  }

  	return $redirect_to;
}

/*
* 	Show admin notice after API / XML bulk action
*/
function tsseph_bulk_action_admin_notice() {
	if(isset($_REQUEST['exported_orders'])) { $exported_orders = absint($_REQUEST['exported_orders']);} else $exported_orders = 0;
	if(isset($_REQUEST['exported_orders_api'])) { $exported_orders_api = absint($_REQUEST['exported_orders_api']);} else $exported_orders_api = 0;
	if(isset($_REQUEST['eph_status'])) { $eph_status = sanitize_text_field($_REQUEST['eph_status']);} else $eph_status = '';
	if(isset($_REQUEST['orders_sent'])) { $orders_sent = sanitize_text_field($_REQUEST['orders_sent']);} else $orders_sent = '';
	if(isset($_REQUEST['orders_not_sent'])) { $orders_not_sent = sanitize_text_field($_REQUEST['orders_not_sent']);} else $orders_not_sent = '';


	if ( $exported_orders != 0 ) {
		echo '<div id="message" class="updated fade"><a href="' .  plugins_url( '..\export\EPH.zip', __FILE__ ) . '" download>'. __('EPH.zip súbor vytvorený.','spirit-eph') . '</a> ' . __('Počet objednávok','spirit-eph') .': ' . $exported_orders . '</div>';
	}
	else if ( $exported_orders_api != 0) {

		if ($orders_sent != "") {
			echo '<div id="message" class="updated fade">' . sprintf( __('Počet odoslaných objednávok: %d', 'spirit-eph'),count(explode(',',$orders_sent))) . ' (' . $orders_sent . ')</div>';
		}
	
		if ($orders_not_sent != "") {
			echo '<div id="message" class="error fade">' . __('Vyskytol sa problém pre objednávky: ', 'spirit-eph') . $orders_not_sent . ' -> ' . $eph_status . '</div>';
		}
	}    
}
  